@@ -72,10 +72,7 @@ class VerifiableClient(object):
                 continue
 
             if n.startswith('topicconf_'):
-                # Apply topicconf_ properties on default.topic.config
-                if 'default.topic.config' not in conf:
-                    conf['default.topic.config'] = dict()
-                conf['default.topic.config'][n[10:]] = v
+                conf[n[10:]] = v
                 continue
 
             if not n.startswith('conf_'):
@@ -91,10 +88,6 @@ class VerifiableClient(object):
                 # "org.apache.kafka.clients.consumer.RangeAssignor" -> "range"
                 conf[n] = re.sub(r'org.apache.kafka.clients.consumer.(\w+)Assignor',
                                  lambda x: x.group(1).lower(), v)
-
-            elif n == 'enable.idempotence':
-                # Ignore idempotence for now, best-effortly.
-                sys.stderr.write('%% WARN: Ignoring unsupported %s=%s\n' % (n, v))
             else:
                 conf[n] = v
 
