@@ -1009,7 +1009,7 @@ static PyObject *Consumer_close (Handle *self, PyObject *ignore) {
 static PyMethodDef Consumer_methods[] = {
 	{ "subscribe", (PyCFunction)Consumer_subscribe,
 	  METH_VARARGS|METH_KEYWORDS,
-	  ".. py:function:: subscribe(topics, [listener=None])\n"
+	  ".. py:function:: subscribe(topics, [on_assign=None], [on_revoke=None])\n"
 	  "\n"
 	  "  Set subscription to supplied list of topics\n"
 	  "  This replaces a previous subscription.\n"
@@ -1236,7 +1236,8 @@ static PyMethodDef Consumer_methods[] = {
           "  :param bool cached: Instead of querying the broker used cached information. "
           "Cached values: The low offset is updated periodically (if statistics.interval.ms is set) while "
           "the high offset is updated on each message fetched from the broker for this partition.\n"
-          "  :returns: Tuple of (low,high) on success or None on timeout.\n"
+          "  :returns: Tuple of (low,high) on success or None on timeout. "
+          "The high offset is the offset of the last message + 1.\n"
           "  :rtype: tuple(int,int)\n"
           "  :raises: KafkaException\n"
           "  :raises: RuntimeError if called on a closed consumer\n"
@@ -1387,6 +1388,7 @@ static int Consumer_init (PyObject *selfobj, PyObject *args, PyObject *kwargs) {
         rd_kafka_poll_set_consumer(self->rk);
 
         self->u.Consumer.rkqu = rd_kafka_queue_get_consumer(self->rk);
+        assert(self->u.Consumer.rkqu);
 
         return 0;
 }
@@ -1423,8 +1425,8 @@ PyTypeObject ConsumerType = {
         "\n"
         ".. py:function:: Consumer(config)\n"
         "\n"
-        "  :param dict config: Configuration properties. At a minimum ``bootstrap.servers`` and "
-        "``group.id`` **should** be set"
+        "  :param dict config: Configuration properties. At a minimum ``group.id`` **must** be set,"
+                " ``bootstrap.servers`` **should** be set"
         "\n"
         "Create new Consumer instance using provided configuration dict.\n"
         "\n"
