@@ -146,9 +146,7 @@ static void dr_msg_cb (rd_kafka_t *rk, const rd_kafka_message_t *rkm,
 
 	msgobj = Message_new0(self, rkm);
 	
-	args = Py_BuildValue("(OO)",
-			     Message_error((Message *)msgobj, NULL),
-			     msgobj);
+        args = Py_BuildValue("(OO)", ((Message *)msgobj)->error, msgobj);
 
 	Py_DECREF(msgobj);
 
