@@ -62,9 +62,12 @@ typedef struct {
 	char *str;   /* Human readable representation of error, if one
 		      * was provided by librdkafka.
 		      * Else falls back on err2str(). */
+        int   fatal; /**< Set to true if a fatal error. */
 } KafkaError;
 
 
+static void cfl_PyErr_Fatal (rd_kafka_resp_err_t err, const char *reason);
+
 static PyObject *KafkaError_code (KafkaError *self, PyObject *ignore) {
 	return cfl_PyInt_FromInt(self->code);
 }
@@ -81,6 +84,20 @@ static PyObject *KafkaError_name (KafkaError *self, PyObject *ignore) {
 	return cfl_PyUnistr(_FromString(rd_kafka_err2name(self->code)));
 }
 
+static PyObject *KafkaError_fatal (KafkaError *self, PyObject *ignore) {
+        PyObject *ret = self->fatal ? Py_True : Py_False;
+        Py_INCREF(ret);
+        return ret;
+}
+
+
+static PyObject *KafkaError_test_raise_fatal (KafkaError *null,
+                                              PyObject *ignore) {
+        cfl_PyErr_Fatal(RD_KAFKA_RESP_ERR__INVALID_ARG,
+                        "This is a fatal exception for testing purposes");
+        return NULL;
+}
+
 
 static PyMethodDef KafkaError_methods[] = {
 	{ "code", (PyCFunction)KafkaError_code, METH_NOARGS,
@@ -105,6 +122,14 @@ static PyMethodDef KafkaError_methods[] = {
 	  "  :rtype: str\n"
 	  "\n"
 	},
+        { "fatal", (PyCFunction)KafkaError_fatal, METH_NOARGS,
+          "  :returns: True if this a fatal error, else False.\n"
+          "  :rtype: bool\n"
+          "\n"
+        },
+        { "_test_raise_fatal", (PyCFunction)KafkaError_test_raise_fatal,
+          METH_NOARGS|METH_STATIC
+        },
 
 	{ NULL }
 };
@@ -133,7 +158,8 @@ static int KafkaError_traverse (KafkaError *self,
 }
 
 static PyObject *KafkaError_str0 (KafkaError *self) {
-	return cfl_PyUnistr(_FromFormat("KafkaError{code=%s,val=%d,str=\"%s\"}",
+	return cfl_PyUnistr(_FromFormat("KafkaError{%scode=%s,val=%d,str=\"%s\"}",
+                                        self->fatal?"FATAL,":"",
 					 rd_kafka_err2name(self->code),
 					 self->code,
 					 self->str ? self->str :
@@ -247,6 +273,7 @@ static PyTypeObject KafkaErrorType = {
 static void KafkaError_init (KafkaError *self,
 			     rd_kafka_resp_err_t code, const char *str) {
 	self->code = code;
+        self->fatal = 0;
 	if (str)
 		self->str = strdup(str);
 	else
@@ -292,6 +319,17 @@ PyObject *KafkaError_new0 (rd_kafka_resp_err_t err, const char *fmt, ...) {
 }
 
 
+/**
+ * @brief Raise exception from fatal error.
+ */
+static void cfl_PyErr_Fatal (rd_kafka_resp_err_t err, const char *reason) {
+        PyObject *eo = KafkaError_new0(err, "%s", reason);
+        ((KafkaError *)eo)->fatal = 1;
+        PyErr_SetObject(KafkaException, eo);
+}
+
+
+
 
 
 /****************************************************************************
@@ -305,6 +343,10 @@ PyObject *KafkaError_new0 (rd_kafka_resp_err_t err, const char *fmt, ...) {
  ****************************************************************************/
 
 
+/**
+ * @returns a Message's error object, if any, else None.
+ * @remark The error object refcount is increased by this function.
+ */
 PyObject *Message_error (Message *self, PyObject *ignore) {
 	if (self->error) {
 		Py_INCREF(self->error);
@@ -1162,6 +1204,7 @@ PyObject *c_headers_to_py (rd_kafka_headers_t *headers) {
 }
 #endif
 
+
 /****************************************************************************
  *
  *
@@ -1177,6 +1220,16 @@ static void error_cb (rd_kafka_t *rk, int err, const char *reason, void *opaque)
 	CallState *cs;
 
 	cs = CallState_get(h);
+
+        /* If the client raised a fatal error we'll raise an exception
+         * rather than calling the error callback. */
+        if (err == RD_KAFKA_RESP_ERR__FATAL) {
+                char errstr[512];
+                err = rd_kafka_fatal_error(rk, errstr, sizeof(errstr));
+                cfl_PyErr_Fatal(err, errstr);
+                goto crash;
+        }
+
 	if (!h->error_cb) {
 		/* No callback defined */
 		goto done;
@@ -1189,6 +1242,7 @@ static void error_cb (rd_kafka_t *rk, int err, const char *reason, void *opaque)
 	if (result)
 		Py_DECREF(result);
 	else {
+        crash:
 		CallState_crash(cs);
 		rd_kafka_yield(h->rk);
 	}
@@ -1579,6 +1633,15 @@ rd_kafka_conf_t *common_conf_setup (rd_kafka_type_t ktype,
                 PyDict_Update(confdict, kwargs);
         }
 
+        if (ktype == RD_KAFKA_CONSUMER && 
+                !PyDict_GetItemString(confdict, "group.id")) {
+
+                PyErr_SetString(PyExc_ValueError,
+                                "Failed to create consumer: group.id must be set");
+                Py_DECREF(confdict);
+                return NULL;
+        }
+
 	conf = rd_kafka_conf_new();
 
         /*
@@ -1766,8 +1829,7 @@ inner_err:
 
         Py_DECREF(confdict);
 
-	if (h->error_cb)
-		rd_kafka_conf_set_error_cb(conf, error_cb);
+        rd_kafka_conf_set_error_cb(conf, error_cb);
 
         if (h->throttle_cb)
                 rd_kafka_conf_set_throttle_cb(conf, throttle_cb);
@@ -1942,6 +2004,9 @@ int cfl_PyObject_SetInt (PyObject *o, const char *name, int val) {
  * @brief Get attribute \p attr_name from \p object and verify it is
  *        of type \p py_type.
  *
+ * @param py_type the value type of \p attr_name must match \p py_type, unless
+ *                \p py_type is NULL.
+ *
  * @returns 1 if \p valp was updated with the object (new reference) or NULL
  *          if not matched and not required, or
  *          0 if an exception was raised.
@@ -1963,7 +2028,7 @@ int cfl_PyObject_GetAttr (PyObject *object, const char *attr_name,
                 return 0;
         }
 
-        if (Py_TYPE(o) != py_type) {
+        if (py_type && Py_TYPE(o) != py_type) {
                 Py_DECREF(o);
                 PyErr_Format(PyExc_TypeError,
                              "Expected .%s to be %s type, not %s",
@@ -2047,7 +2112,10 @@ int cfl_PyObject_GetString (PyObject *object, const char *attr_name,
 #ifdef PY3
                                   &PyUnicode_Type,
 #else
-                                  &PyString_Type,
+                                  /* Python 2: support both str and unicode
+                                   *           let PyObject_Unistr() do the
+                                   *           proper conversion below. */
+                                  NULL,
 #endif
                                   required))
                 return 0;
@@ -2119,8 +2187,13 @@ static PyObject *libversion (PyObject *self, PyObject *args) {
 			     rd_kafka_version());
 }
 
+/*
+ * Version hex representation
+ * 0xMMmmRRPP
+ * MM=major, mm=minor, RR=revision, PP=patchlevel (not used)
+ */
 static PyObject *version (PyObject *self, PyObject *args) {
-	return Py_BuildValue("si", "0.11.6", 0x000b0600);
+	return Py_BuildValue("si", "1.1.0", 0x01010000);
 }
 
 static PyMethodDef cimpl_methods[] = {
@@ -2219,7 +2292,7 @@ static char *KafkaError_add_errs (PyObject *dict, const char *origdoc) {
 static struct PyModuleDef cimpl_moduledef = {
 	PyModuleDef_HEAD_INIT,
 	"cimpl",                                  /* m_name */
-	"Confluent's Apache Kafka Python client (C implementation)", /* m_doc */
+	"Confluent's Python client for Apache Kafka (C implementation)", /* m_doc */
 	-1,                                       /* m_size */
 	cimpl_methods,                            /* m_methods */
 };
@@ -2250,7 +2323,7 @@ static PyObject *_init_cimpl (void) {
 	m = PyModule_Create(&cimpl_moduledef);
 #else
 	m = Py_InitModule3("cimpl", cimpl_methods,
-			   "Confluent's Apache Kafka Python client (C implementation)");
+			   "Confluent's Python client for Apache Kafka (C implementation)");
 #endif
 	if (!m)
 		return NULL;
